@@ -14,7 +14,7 @@ from .constants import VALUE_UNITS, PACKAGE_TYPES, POWER_UNITS, INTERFACE_TYPES,
     NUMBER_ITEM_LEN_DEFAULT, NUMBER_ITEM_LEN_MIN, NUMBER_ITEM_LEN_MAX, NUMBER_VARIATION_LEN_DEFAULT, NUMBER_VARIATION_LEN_MIN, NUMBER_VARIATION_LEN_MAX
 from .models import Part, PartClass, Manufacturer, ManufacturerPart, Subpart, Seller, SellerPart, User, UserMeta, \
     Organization, PartRevision, AssemblySubparts, Assembly
-from .validators import decimal, numeric
+from .validators import decimal, numeric, alphanumeric
 from .utils import listify_string, stringify_list, check_references_for_duplicates, prep_for_sorting_nicely, get_from_dict
 from .csv_headers import PartsListCSVHeaders, PartClassesCSVHeaders, BOMFlatCSVHeaders, BOMIndentedCSVHeaders, CSVHeaderError
 
@@ -254,7 +254,7 @@ class PartClassForm(forms.ModelForm):
     def clean_code(self):
         cleaned_data = super(PartClassForm, self).clean()
         code = cleaned_data.get('code')
-        if PartClass.objects.filter(code=code, organization=self.organization).count() > 0:
+        if PartClass.objects.filter(code=code, organization=self.organization).exclude(pk=self.instance.pk).count() > 0:
             validation_error = forms.ValidationError(f"Part class with code {code} is already defined.", code='invalid')
             self.add_error('code', validation_error)
         return code
@@ -347,9 +347,9 @@ class PartClassCSVForm(forms.Form):
                         continue
 
                     description_or_comment = ''
-                    if 'description' is not None:
+                    if description is not None:
                         description_or_comment = description
-                    elif 'comment' is not None:
+                    elif comment is not None:
                         description_or_comment = comment
                     PartClass.objects.create(code=code, name=name, comment=description_or_comment, organization=self.organization)
                     self.successes.append("Part class {0} {1} on row {2} created.".format(code, name, row_count))
@@ -461,7 +461,7 @@ class PartCSVForm(forms.Form):
                     try:
                         part_class = PartClass.objects.get(code=part_data[csv_headers.get_default('part_class')], organization=self.organization)
                     except PartClass.DoesNotExist:
-                        self.add_error(None, "Part class {0} in row {1} doesn't exist. "
+                        self.add_error(None, "Part class {0} in row {1} doesn't exist. Create part class on Settings > IndaBOM and try again."
                                              "Uploading of this part skipped.".format(part_data[csv_headers.get_default('part_class')], row_count))
                         continue
                 else:
@@ -469,7 +469,7 @@ class PartCSVForm(forms.Form):
                     continue
 
                 if not revision:
-                    self.add_error(None, "Missing revision in row {}. Uploading of this part skipped.", format(row_count))
+                    self.add_error(None, f"Missing revision in row {row_count}. Uploading of this part skipped.")
                     continue
                 elif len(revision) > 4:
                     self.add_error(None, "Revision {0} in row {1} is more than the maximum 4 characters. "
@@ -629,6 +629,7 @@ class PartFormSemiIntelligent(forms.ModelForm):
     def __init__(self, *args, **kwargs):
         self.organization = kwargs.pop('organization', None)
         super(PartFormSemiIntelligent, self).__init__(*args, **kwargs)
+        self.fields['number_item'].validators.append(alphanumeric)
         self.fields['number_class'] = forms.ModelChoiceField(queryset=PartClass.objects.filter(organization=self.organization),
                                                              empty_label="- Select Part Number Class -", label='Part Number Class*', required=True)
         if self.instance and self.instance.id:
@@ -653,7 +654,7 @@ class PartFormSemiIntelligent(forms.ModelForm):
             self.add_error('number_class', validation_error)
 
         try:
-            if number_item != '':
+            if number_item is not None and number_item != '':
                 Part.verify_format_number_item(number_item, self.organization)
         except AttributeError as e:
             validation_error = forms.ValidationError(str(e), code='invalid')
