@@ -113,7 +113,7 @@ class Manufacturer(models.Model, AsDictModel):
 class Part(models.Model):
     organization = models.ForeignKey(Organization, on_delete=models.CASCADE, db_index=True)
     number_class = models.ForeignKey(PartClass, default=None, blank=True, null=True, related_name='number_class', on_delete=models.PROTECT, db_index=True)
-    number_item = models.CharField(max_length=NUMBER_ITEM_LEN_MAX, default=None, blank=True, validators=[alphanumeric])
+    number_item = models.CharField(max_length=NUMBER_ITEM_LEN_MAX, default=None, blank=True)
     number_variation = models.CharField(max_length=2, default=None, blank=True, null=True, validators=[alphanumeric])
     primary_manufacturer_part = models.ForeignKey('ManufacturerPart', default=None, null=True, blank=True,
                                                   on_delete=models.SET_NULL, related_name='primary_manufacturer_part')
@@ -380,7 +380,7 @@ class PartRevision(models.Model):
         s += verbosify(self.width, units=self.width_units if make_searchable else self.get_width_units_display(), pre='W')
         s += verbosify(self.height, units=self.height_units if make_searchable else self.get_height_units_display(), pre='H')
         s += verbosify(self.weight, units=self.weight_units if make_searchable else self.get_weight_units_display())
-        return s
+        return s[:255]
 
     def synopsis(self, return_displayable=True):
         return self.displayable_synopsis if return_displayable else self.searchable_synopsis
